Useful tools for websrapping textbook centre images

# Description
    
It consists of two main modules:

- `beautifulsoup4`: tool for webscapping
- `pysimplegui`: tools to work with python GUI

# Installation
 
## Normal installation

```bash
pip install dentoscrapper
```
## Usage

```bash
python3 -m tbcscrapper
```

## Development installation

```bash
git clone https://github.com/Denniskamau/TextbookcentreWebScrapper

```
